@@ -1,14 +1,14 @@
 use proc_macro::TokenStream;
 
 use quote::{quote, format_ident, ToTokens};
-use syn::{parse_macro_input, parse_quote, ItemStruct, ItemImpl, ImplItem, ImplItemMethod, Fields};
+use syn::{parse_macro_input, parse_quote, ItemStruct, ItemImpl, ImplItem, ImplItemMethod, Fields, LitInt};
 
 #[proc_macro_attribute]
 /// Defines a struct that will act as a VTable to a C++ class.
 /// It can also take data as to make sure the class functions as expected.
 /// # Example
 /// ```cpp
-/// #define interface __declspec(novtable) class
+/// #define interface class __declspec(novtable)
 /// interface MathEngine {
 /// public:
 ///         virtual int add(int x, int y) = 0;
@@ -83,7 +83,7 @@ pub fn vtable(_attr: TokenStream, item: TokenStream) -> TokenStream {
 					for attr in &f.attrs {
 						let s = attr.path.to_token_stream();
 						if s.to_string() == "offset" {
-							let offset: syn::LitInt = attr.parse_args().unwrap();
+							let offset: syn::LitInt = attr.parse_args().expect("Expected integer for offset");
 							count = offset.base10_parse::<usize>().expect("Offset must be usize");
 							break;
 						}
@@ -120,6 +120,8 @@ pub fn vtable(_attr: TokenStream, item: TokenStream) -> TokenStream {
 						}
 					};
 
+					item.vis = f.vis.clone();
+
 					item.block.stmts.push( syn::Stmt::Expr( syn::Expr::Call(call) ) );
 					interface.items.push( ImplItem::Method(item) );
 					count += 1;
@@ -136,7 +138,7 @@ pub fn vtable(_attr: TokenStream, item: TokenStream) -> TokenStream {
 	let mut struc: ItemStruct = parse_quote! {
 		#[repr(C)]
 		struct #ident {
-			vtable: *mut *mut usize,
+			pub vtable: *mut *mut usize,
 		}
 	};
 
